@@ -56,10 +56,10 @@ class Api():
         self.header = {'Content-Type': 'application/json',
                        'Accept': 'application/json',
                        'Accept-Encoding': 'message/rfc822'}
-        self.session = Session()
-        retry = Retry(connect=3, backoff_factor=0.5)
-        adapter = HTTPAdapter(max_retries=retry)
-        self.session.mount('http://', adapter)
+        # self.session = Session()
+        # retry = Retry(connect=3, backoff_factor=0.5)
+        # adapter = HTTPAdapter(max_retries=retry)
+        # self.session.mount('http://', adapter)
 
     def __to_format(self, response):
         """A private method to return the API response in the desired format
@@ -82,9 +82,13 @@ class Api():
             @param self - the object pointer
             @param url - API URL to access
         """
+        session = Session()
+        retry = Retry(connect=3, backoff_factor=0.5)
+        adapter = HTTPAdapter(max_retries=retry)
+        session.mount('http://', adapter)
         req = Request('POST',url, data=json.dumps(content), headers=self.header)
         prep = req.prepare()
-        resq = self.session.send(prep,
+        resq = session.send(prep,
         stream=None,
         verify=None
         )
